@@ -5,18 +5,19 @@ import numpy as np
 
 from sahi.prediction import ObjectPrediction
 from sahi.utils.torch import cuda_is_available, empty_cuda_cache
+from typing import List, Dict, Optional, Union
 
 
 class DetectionModel:
     def __init__(
         self,
-        model_path=None,
-        config_path=None,
-        device=None,
+        model_path: str,
+        config_path: Optional[str] = None,
+        device: Optional[str] = None,
         mask_threshold: float = 0.5,
         prediction_score_threshold: float = 0.3,
-        category_mapping=None,
-        category_remapping=None,
+        category_mapping: Optional[Dict] = None,
+        category_remapping: Optional[Dict] = None,
         load_at_init: bool = True,
     ):
         """
@@ -87,8 +88,8 @@ class DetectionModel:
 
     def _create_object_prediction_list_from_original_predictions(
         self,
-        shift_amount=[0, 0],
-        full_shape=None,
+        shift_amount: Optional[List[int]] = [0, 0],
+        full_shape: Optional[List[int]] = None,
     ):
         """
         This function should be implemented in a way that self._original_predictions should
@@ -119,8 +120,8 @@ class DetectionModel:
 
     def convert_original_predictions(
         self,
-        shift_amount=[0, 0],
-        full_shape=None,
+        shift_amount: Optional[List[int]] = [0, 0],
+        full_shape: Optional[List[int]] = None,
     ):
         """
         Converts original predictions of the detection model to a list of
@@ -147,7 +148,9 @@ class DetectionModel:
     def original_predictions(self):
         return self._original_predictions
 
-    def _create_predictions_from_object_prediction_list(object_prediction_list):
+    def _create_predictions_from_object_prediction_list(
+        object_prediction_list: List[ObjectPrediction],
+    ):
         """
         This function should be implemented in a way that it converts a list of
         prediction.ObjectPrediction instance to detection model's original prediction format.
@@ -249,8 +252,8 @@ class MmdetDetectionModel(DetectionModel):
 
     def _create_object_prediction_list_from_original_predictions(
         self,
-        shift_amount=[0, 0],
-        full_shape=None,
+        shift_amount: Optional[List[int]] = [0, 0],
+        full_shape: Optional[List[int]] = None,
     ):
         """
         self._original_predictions is converted to a list of prediction.ObjectPrediction and set to
@@ -306,7 +309,7 @@ class MmdetDetectionModel(DetectionModel):
 
     def _create_original_predictions_from_object_prediction_list(
         self,
-        object_prediction_list,
+        object_prediction_list: List[ObjectPrediction],
     ):
         """
         Converts a list of prediction.ObjectPrediction instance to detection model's original prediction format.
@@ -355,3 +358,145 @@ class MmdetDetectionModel(DetectionModel):
             original_predictions = boxes
 
         return original_predictions
+
+
+class Yolov5DetectionModel(DetectionModel):
+    def load_model(self):
+        """
+        Detection model is initialized and set to self.model.
+        """
+        try:
+            import yolov5
+        except ImportError:
+            raise ImportError(
+                'Please run "pip install -U yolov5" '
+                "to install YOLOv5 first for YOLOv5 inference."
+            )
+
+        from mmdet.apis import init_detector
+
+        # set model
+        try:
+            model = yolov5.load(self.model_path, device=self.device)
+            self.model = model
+        except Exception as e:
+            TypeError("model_path is not a valid yolov5 model path: ", e)
+
+        # set category_mapping
+        if not self.category_mapping:
+            category_mapping = {
+                str(ind): category_name
+                for ind, category_name in enumerate(self.category_names)
+            }
+            self.category_mapping = category_mapping
+
+    def perform_inference(self, image: np.ndarray):
+        """
+        Prediction is performed using self.model and the prediction result is set to self._original_predictions.
+
+        Args:
+            image: np.ndarray
+                A numpy array that contains the image to be predicted.
+        """
+        try:
+            import yolov5
+        except ImportError:
+            raise ImportError(
+                'Please run "pip install -U yolov5" '
+                "to install YOLOv5 first for YOLOv5 inference."
+            )
+
+        # Confirm model is loaded
+        assert (
+            self.model is not None
+        ), "Model is not loaded, load it by calling .load_model()"
+
+        prediction_result = self.model(image)
+
+        self._original_predictions = prediction_result
+
+    @property
+    def num_categories(self):
+        """
+        Returns number of categories
+        """
+        return len(self.model.names)
+
+    @property
+    def has_mask(self):
+        """
+        Returns if model output contains segmentation mask
+        """
+        has_mask = self.model.with_mask
+        return has_mask
+
+    @property
+    def category_names(self):
+        return self.model.names
+
+    def _create_object_prediction_list_from_original_predictions(
+        self,
+        shift_amount: Optional[List[int]] = [0, 0],
+        full_shape: Optional[List[int]] = None,
+    ):
+        """
+        self._original_predictions is converted to a list of prediction.ObjectPrediction and set to
+        self._object_prediction_list.
+
+        Args:
+            shift_amount: list
+                To shift the box and mask predictions from sliced image to full sized image, should be in the form of [shift_x, shift_y]
+            full_shape: list
+                Size of the full image after shifting, should be in the form of [height, width]
+        """
+        original_predictions = self._original_predictions
+
+        # handle only first image (batch=1)
+        predictions_in_xyxy_format = original_predictions.xyxy[0]
+
+        object_prediction_list = []
+
+        # process predictions
+        for prediction in predictions_in_xyxy_format:
+            x1 = int(prediction[0].item())
+            y1 = int(prediction[1].item())
+            x2 = int(prediction[2].item())
+            y2 = int(prediction[3].item())
+            bbox = [x1, y1, x2, y2]
+            score = prediction[4].item()
+            category_id = int(prediction[5].item())
+            category_name = original_predictions.names[category_id]
+
+            object_prediction = ObjectPrediction(
+                bbox=bbox,
+                category_id=category_id,
+                score=score,
+                bool_mask=None,
+                category_name=category_name,
+                shift_amount=shift_amount,
+                full_shape=full_shape,
+            )
+            object_prediction_list.append(object_prediction)
+
+        self._object_prediction_list = object_prediction_list
+
+    def _create_original_predictions_from_object_prediction_list(
+        self,
+        object_prediction_list: List[ObjectPrediction],
+    ):
+        """
+        Converts a list of prediction.ObjectPrediction instance to detection model's original
+        prediction format. Then returns the converted predictions.
+        Can be considered as inverse of _create_object_prediction_list_from_predictions().
+
+        Args:
+            object_prediction_list: a list of prediction.ObjectPrediction
+        Returns:
+            original_predictions: a list of converted predictions in models original output format
+        """
+        assert self.original_predictions is not None, (
+            "self.original_predictions"
+            " cannot be empty, call .perform_inference() first"
+        )
+        # TODO: implement object_prediction_list to yolov5 format conversion
+        NotImplementedError()
